@@ -4,12 +4,8 @@ use std::{
     sync::Arc,
 };
 
-use aliri::{
-    jwa, jwk,
-    jwt::{self, CoreClaims},
-    Jwk, Jwks, Jwt,
-};
-use aliri_oauth2::{jwt::BasicClaimsWithScope, Authority, HasScopes, Scopes, ScopesPolicy};
+use aliri::{jwa, jwk, jwt, jwt::CoreClaims as _, Jwk, Jwks, Jwt};
+use aliri_oauth2::{oauth2, oauth2::HasScope as _, Authority, ScopePolicy};
 use aliri_warp;
 use color_eyre::Result;
 use warp::{Filter, Reply};
@@ -82,14 +78,16 @@ async fn main() -> Result<()> {
             Arc::clone(&jwks),
             Arc::new(validator.clone()),
         ))
-        .map(|param, agent: String, claims: BasicClaimsWithScope| {
-            format!(
-                "Hello {}, whose agent is {}, authorized as {}!",
-                param,
-                agent,
-                claims.sub().unwrap()
-            )
-        });
+        .map(
+            |param, agent: String, claims: oauth2::BasicClaimsWithScope| {
+                format!(
+                    "Hello {}, whose agent is {}, authorized as {}!",
+                    param,
+                    agent,
+                    claims.sub().unwrap()
+                )
+            },
+        );
 
     let jwks_url = format!("http://{}/.well-known/jwks.json", addr);
     let authority = Authority::new_from_url(jwks_url, validator).await?;
@@ -99,30 +97,32 @@ async fn main() -> Result<()> {
         authority.clone(),
     ));
 
-    let mut policy = ScopesPolicy::deny_all();
-    policy.allow(Scopes::single("say:hello"));
-    policy.allow(Scopes::from_scopes(vec![
-        "say:anything",
-        "no-really:anything",
+    let mut policy = ScopePolicy::deny_all();
+    policy.allow(oauth2::Scope::single("say:hello".parse()?));
+    policy.allow(oauth2::Scope::from_scope_tokens(vec![
+        "say:anything".parse()?,
+        "no-really:anything".parse()?,
     ]));
 
     let hi4 = warp::path!("hello4" / String)
         .and(warp::get())
         .and(warp::header("user-agent"))
-        .and(aliri_warp::oauth2::require_scopes(
+        .and(aliri_warp::oauth2::require_scope(
             aliri_warp::jwt(),
             authority,
             Arc::new(policy),
         ))
-        .map(|param, agent: String, claims: BasicClaimsWithScope| {
-            format!(
-                "Hello {}, whose agent is {}, authorized as {} with scopes {:?}!",
-                param,
-                agent,
-                claims.sub().unwrap(),
-                claims.scopes()
-            )
-        });
+        .map(
+            |param, agent: String, claims: oauth2::BasicClaimsWithScope| {
+                format!(
+                    "Hello {}, whose agent is {}, authorized as {} with scope {:?}!",
+                    param,
+                    agent,
+                    claims.sub().unwrap(),
+                    claims.scope()
+                )
+            },
+        );
 
     let (addr, fut) =
         warp::serve(hi.or(hi2).or(hi3).or(hi4)).bind_ephemeral((Ipv4Addr::LOCALHOST, 0));
